@@ -262,18 +262,35 @@ public:
 	void set_keep_alive(int timeout) { this->keep_alive_timeo = timeout; }
 
 public:
-	/* noreply(), push() are for server tasks only. */
+	/* Do not reply this request. */
 	void noreply()
 	{
 		if (this->state == WFT_STATE_TOREPLY)
 			this->state = WFT_STATE_NOREPLY;
 	}
 
+	/* Push reply data synchronously. */
 	virtual int push(const void *buf, size_t size)
 	{
 		return this->scheduler->push(buf, size, this);
 	}
 
+	/* To check if the connection was closed before replying.
+	   Always returns 'true' in callback. */
+	bool closed() const
+	{
+		switch (this->state)
+		{
+		case WFT_STATE_UNDEFINED:
+			return false;
+		case WFT_STATE_TOREPLY:
+		case WFT_STATE_NOREPLY:
+			return !this->get_target()->has_idle_conn();
+		default:
+			return true;
+		}
+	}
+
 public:
 	void set_callback(std::function<void (WFNetworkTask<REQ, RESP> *)> cb)
 	{
